package qcow-stream

  1. Overview
  2. Docs

Module Qcow_mappingSource

Sourcetype t
Sourceval create : int64 -> t
Sourceval extend : t -> int64 -> unit
Sourceval get : t -> int64 -> int64
Sourceval set : t -> int64 -> int64 -> unit
Sourceval length : t -> int64
Sourceval to_interval_seq : t -> int64 -> (int64 * int64) Seq.t

to_interval_seq t cluster_bits returns a sequence of allocated virtual data cluster intervals, intended to be used with sparse disks.

Thus, for a physical image represented by an array of physical clusters and their corresponding virtual clusters: -1; 1; 2; 3; 7; -1; 4

to_interval_seq will return: (1,3); (7,7); (4,4)